unit UFormOptions;

{$mode delphi}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  Spin, ComCtrls, ExtCtrls, UTarget, UTheme;

type

  { TFormOptions }

  TFormOptions = class(TForm)
    ButtonOk: TButton;
    ButtonCancel: TButton;
    CheckBox1: TCheckBox;
    CheckBoxDPIAuto: TCheckBox;
    CheckBoxOptimizeAddSub: TCheckBox;
    CheckBoxOptimizeCopyMultiply: TCheckBox;
    CheckBoxOptimizeMerge: TCheckBox;
    CheckBoxOptimizeRelativeIndexes: TCheckBox;
    ComboBoxLanguage: TComboBox;
    ComboBoxOptimization: TComboBox;
    ComboBoxTheme: TComboBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    LabelDPI: TLabel;
    LabelTheme: TLabel;
    LabelX: TLabel;
    PageControl1: TPageControl;
    Panel1: TPanel;
    Panel2: TPanel;
    SpinEditCellSize: TSpinEdit;
    SpinEditDPIX: TSpinEdit;
    SpinEditDPIY: TSpinEdit;
    SpinEditMemorySize: TSpinEdit;
    TabSheetGeneral: TTabSheet;
    TabSheetBuild: TTabSheet;
    procedure CheckBoxDPIAutoChange(Sender: TObject);
    procedure FormClose(Sender: TObject; var CloseAction: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    { private declarations }
  public
    procedure UpdateInterface;
    procedure Load;
    procedure Save;
  end;

var
  FormOptions: TFormOptions;

implementation

{$R *.lfm}

uses
  UCore, ULanguages;

{ TFormOptions }

procedure TFormOptions.FormShow(Sender: TObject);
begin
  Core.PersistentForm1.Load(Self);
end;

procedure TFormOptions.UpdateInterface;
begin
  SpinEditDPIX.Enabled := not CheckBoxDPIAuto.Checked;
  SpinEditDPIY.Enabled := not CheckBoxDPIAuto.Checked;
  LabelDPI.Enabled := not CheckBoxDPIAuto.Checked;
  LabelX.Enabled := not CheckBoxDPIAuto.Checked;
  if CheckBoxDPIAuto.Checked then begin
    SpinEditDPIX.Value := ScreenInfo.PixelsPerInchX;
    SpinEditDPIY.Value := ScreenInfo.PixelsPerInchY;
  end;
  CheckBoxOptimizeAddSub.Enabled := ComboBoxOptimization.ItemIndex > 0;
  CheckBoxOptimizeMerge.Enabled := ComboBoxOptimization.ItemIndex > 0;
  CheckBoxOptimizeRelativeIndexes.Enabled := ComboBoxOptimization.ItemIndex > 0;
  CheckBoxOptimizeCopyMultiply.Enabled := ComboBoxOptimization.ItemIndex > 0;
end;

procedure TFormOptions.Load;
begin
  ComboBoxLanguage.ItemIndex := ComboBoxLanguage.Items.IndexOfObject(Core.CoolTranslator1.Language);
  if ComboBoxLanguage.ItemIndex = -1 then ComboBoxLanguage.ItemIndex := 0;
  ComboBoxTheme.ItemIndex := ComboBoxTheme.Items.IndexOfObject(Core.ThemeManager.Theme);
  if ComboBoxTheme.ItemIndex = -1 then ComboBoxTheme.ItemIndex := 0;
  CheckBox1.Checked := Core.OpenProjectOnStart;
  CheckBoxOptimizeAddSub.Checked := Core.Optimizations.AddSub;
  CheckBoxOptimizeMerge.Checked := Core.Optimizations.Merge;
  CheckBoxOptimizeRelativeIndexes.Checked := Core.Optimizations.RelativeIndexes;
  CheckBoxOptimizeCopyMultiply.Checked := Core.Optimizations.CopyMultiply;
  SpinEditDPIX.Value := Core.ScaleDPI1.DPI.X;
  SpinEditDPIY.Value := Core.ScaleDPI1.DPI.Y;
  CheckBoxDPIAuto.Checked := Core.ScaleDPI1.AutoDetect;
  ComboBoxOptimization.ItemIndex := Integer(Core.OptimizationLevel);
  SpinEditCellSize.Value := Core.CellSize;
  SpinEditMemorySize.Value := Core.MemorySize;
  UpdateInterface;
end;

procedure TFormOptions.Save;
begin
  if ComboBoxLanguage.ItemIndex <> -1 then
    Core.CoolTranslator1.Language := TLanguage(ComboBoxLanguage.Items.Objects[ComboBoxLanguage.ItemIndex]);
  if ComboBoxTheme.ItemIndex <> -1 then
    Core.ThemeManager.Theme := TTheme(ComboBoxTheme.Items.Objects[ComboBoxTheme.ItemIndex]);
  Core.OpenProjectOnStart := CheckBox1.Checked;
  Core.ScaleDPI1.DPI := Point(SpinEditDPIX.Value, SpinEditDPIY.Value);
  Core.ScaleDPI1.AutoDetect := CheckBoxDPIAuto.Checked;
  Core.OptimizationLevel := TCompilerOptimization(ComboBoxOptimization.ItemIndex);
  Core.CellSize := SpinEditCellSize.Value;
  Core.MemorySize := SpinEditMemorySize.Value;
  Core.Optimizations.AddSub := CheckBoxOptimizeAddSub.Checked;
  Core.Optimizations.Merge := CheckBoxOptimizeMerge.Checked;
  Core.Optimizations.RelativeIndexes := CheckBoxOptimizeRelativeIndexes.Checked;
  Core.Optimizations.CopyMultiply := CheckBoxOptimizeCopyMultiply.Checked;
end;

procedure TFormOptions.CheckBoxDPIAutoChange(Sender: TObject);
begin
  UpdateInterface;
end;

procedure TFormOptions.FormClose(Sender: TObject; var CloseAction: TCloseAction
  );
begin
  Core.PersistentForm1.Save(Self);
end;

procedure TFormOptions.FormCreate(Sender: TObject);
begin
  Core.CoolTranslator1.TranslateComponentRecursive(Self);
  Core.ThemeManager.UseTheme(Self);
  Core.ThemeManager.Themes.LoadToStrings(ComboBoxTheme.Items);
  Core.CoolTranslator1.LanguageListToStrings(ComboBoxLanguage.Items);
end;

end.

